@@ -1,16 +1,17 @@
 #!/usr/bin/env python
 
+import hashlib
+import ssl
+import zipfile
+import site
+from urllib import request
+import ctypes
 import os
 import sys
 import logging
 logger = logging.getLogger(__name__)
-import ctypes
-from urllib import request
-import site
-import zipfile
-import ssl
 ssl._create_default_https_context = ssl._create_unverified_context
-import hashlib
+
 
 def get_file_md5(file_path):
     hash_md5 = hashlib.md5()
@@ -19,25 +20,26 @@ def get_file_md5(file_path):
             hash_md5.update(chunk)
     return hash_md5.hexdigest()
 
+
 def _check_download_and_extract_sdk():
     agora_service_path = os.path.dirname(os.path.abspath(__file__))
     sdk_dir = os.path.join(agora_service_path, "agora_sdk")
     zip_path = os.path.join(agora_service_path, "agora_rtc_sdk.zip")
 
-    url = "https://download.agora.io/sdk/release/agora_rtc_sdk_linux_v4.4.30-20241003_233327-366740.zip"
+    url = "https://download.agora.io/sdk/release/agora_rtc_sdk-x86_64-linux-gnu-v4.4.30-20241024_101940-398537.zip"
     libagora_rtc_sdk_path = os.path.join(sdk_dir, "libagora_rtc_sdk.so")
-    rtc_md5 = "f3d5ac80cd56547b0a784f7489f0aca6"
+    rtc_md5 = "7031dd10d1681cd88fd89d68c5b54282"
     if sys.platform == 'darwin':
-        url = "https://download.agora.io/sdk/release/agora_rtc_sdk_mac_v4.4.30_22172_FULL_20241004_0009_366745.zip"
+        url = "https://download.agora.io/sdk/release/agora_rtc_sdk_mac_rel.v4.4.30_22472_FULL_20241024_1224_398653.zip"
         libagora_rtc_sdk_path = os.path.join(sdk_dir, "libAgoraRtcKit.dylib")
-        rtc_md5 = "338a4e4816ada2300c6cbd196b74e220"
+        rtc_md5 = "ca3ca14f9e2b7d97eb2594d1f32dab9f"
 
     if os.path.exists(libagora_rtc_sdk_path) and get_file_md5(libagora_rtc_sdk_path) == rtc_md5:
         return
 
     logger.error("missing agora sdk, now download it, please wait for a while...")
     if os.path.exists(sdk_dir):
-        os.system(f"rm -rf {sdk_dir}")        
+        os.system(f"rm -rf {sdk_dir}")
     os.makedirs(agora_service_path, exist_ok=True)
     if os.path.exists(zip_path):
         os.remove(zip_path)
@@ -52,6 +54,7 @@ def _check_download_and_extract_sdk():
 
     if os.path.exists(zip_path):
         os.remove(zip_path)
+    logger.error("download done, continue...")
 
 
 _check_download_and_extract_sdk()
@@ -61,15 +64,15 @@ lib_path = os.path.join(sdk_dir, 'agora_sdk')
 
 try:
     if sys.platform == 'darwin':
-        lib_agora_rtc_path =os.path.join(lib_path, 'libAgoraRtcKit.dylib')
+        lib_agora_rtc_path = os.path.join(lib_path, 'libAgoraRtcKit.dylib')
         agora_lib = ctypes.CDLL(lib_agora_rtc_path)
 
     elif sys.platform == 'linux':
-        lib_agora_rtc_path =os.path.join(lib_path, 'libagora_rtc_sdk.so')
+        lib_agora_rtc_path = os.path.join(lib_path, 'libagora_rtc_sdk.so')
         ctypes.CDLL(os.path.join(lib_path, 'libagora-fdkaac.so'))
         ctypes.CDLL(os.path.join(lib_path, 'libaosl.so'))
-        agora_lib = ctypes.CDLL(lib_agora_rtc_path)    
+        agora_lib = ctypes.CDLL(lib_agora_rtc_path)
 except OSError as e:
     logger.error(f"Error loading the library: {e}")
     logger.error(f"Attempted to load from: {lib_agora_rtc_path}")
-    sys.exit(1)
\ No newline at end of file
+    sys.exit(1)
